// JavaScript Document

function translateText(text) {
    var translations = {
      'de': { // German
        '8 Characters': '8 Zeichen',
        'Contains Number': 'Enthält Nummer',
        'Contains Uppercase': 'Enthält Großbuchstaben',
        'Contains Special Character': 'Enthält Sonderzeichen',
        'Online Password Strength Checker': 'Online Passwortstärkeprüfer',
        'Write or paste the password here': 'Schreiben oder fügen Sie das Passwort hier ein',
        'Show Password': 'Passwort anzeigen',
        'Copy Password': 'Passwort kopieren',
        'Password copied!': 'Passwort kopiert!'
      },
      'es': { // Spanish
        '8 Characters': '8 Caracteres',
        'Contains Number': 'Contiene Número',
        'Contains Uppercase': 'Contiene Mayúscula',
        'Contains Special Character': 'Contiene Carácter Especial',
        'Online Password Strength Checker': 'Comprobador de Fortaleza de Contraseña en Línea',
        'Write or paste the password here': 'Escriba o pegue la contraseña aquí',
        'Show Password': 'Mostrar contraseña',
        'Copy Password': 'Copiar contraseña',
        'Password copied!': '¡Contraseña copiada!'
      },
      'pt': { // Portuguese
        '8 Characters': '8 Caracteres',
        'Contains Number': 'Contém Número',
        'Contains Uppercase': 'Contém Maiúscula',
        'Contains Special Character': 'Contém Caractere Especial',
        'Online Password Strength Checker': 'Verificador de Força de Senha Online',
        'Write or paste the password here': 'Escreva ou cole a senha aqui',
        'Show Password': 'Mostrar senha',
        'Copy Password': 'Copiar senha',
        'Password copied!': 'Senha copiada!'
      },
      'hu': { // Hungarian
        '8 Characters': '8 Karakter hosszú',
        'Contains Number': 'Tartalmaz Számot',
        'Contains Uppercase': 'Tartalmaz Nagybetűt',
        'Contains Special Character': 'Tartalmaz Különleges Karaktert',
        'Online Password Strength Checker': 'Online Jelszóerő-ellenőrző',
        'Write or paste the password here': 'Írja vagy illessze be a jelszót ide',
        'Show Password': 'Jelszó megjelenítése',
        'Copy Password': 'Jelszó másolása',
        'Password copied!': 'Jelszó másolva!'
      }
    };

    // Felhasználó preferált nyelveinek lekérése az Accept-Language fejlécből
    var userLanguages = navigator.languages || [navigator.language || navigator.userLanguage];
    var userLanguage;

    // A felhasználó preferált nyelv megkeresése a rendelkezésre álló fordítások között
    for (var i = 0; i < userLanguages.length; i++) {
        if (translations[userLanguages[i]]) {
            userLanguage = userLanguages[i];
            break;
        }
    }

    // Ha nincs megtalálható fordítás a felhasználó preferált nyelvén, alapértelmezettként az angol fordítást használjuk
    var translation = translations[userLanguage] || translations['en'];

    // Visszaadjuk a fordított szöveget, ha van fordítás, különben az eredetit
    return translation[text] || text;
}

window.onload = function() {
    var criteriaListItems = document.querySelectorAll('.twdpsc_input_container_check_item');
    criteriaListItems.forEach(function(item) {
      var text = item.textContent.trim();
      item.textContent = translateText(text);
    });

    var title = document.querySelector('.twdpsc_title');
    title.textContent = translateText(title.textContent.trim());

    var passwordInputPlaceholder = document.getElementById('passwordInput');
    passwordInputPlaceholder.placeholder = translateText(passwordInputPlaceholder.placeholder);
    
    // Fordítás "Show Password" gombhoz
    var showPasswordButton = document.querySelector('.twdpsc_spsw');
    showPasswordButton.textContent = translateText(showPasswordButton.textContent);
    
    // Fordítás "Copy Password" gombhoz
    var copyPasswordButton = document.querySelector('.twdpsc_cpsw');
    copyPasswordButton.textContent = translateText(copyPasswordButton.textContent);
    
    // Fordítás "Password copied!" üzenethez
    var copyMessage = document.querySelector('.twdpsc_copymessage');
    copyMessage.textContent = translateText(copyMessage.textContent);
};

function togglePasswordVisibility() {
    const passwordInput = document.getElementById("passwordInput");
    if (passwordInput.type === "password") {
        passwordInput.type = "text";
    } else {
        passwordInput.type = "password";
    }
}

function copyPassword() {
    const passwordInput = document.getElementById("passwordInput");
    passwordInput.select();
    document.execCommand("copy");
    const copyMessage = document.getElementsByClassName("twdpsc_copymessage")[0];
    copyMessage.classList.add("twdpsc_copymessage_show"); // "show" osztály hozzáadása a message div-hez a láthatóvá tételhez
    setTimeout(function() {
        copyMessage.classList.remove("twdpsc_copymessage_show"); // "show" osztály eltávolítása 2 másodperc után a message div elrejtéséhez
    }, 2000);
}

function checkPassword() {
    const password = document.getElementById("passwordInput").value;
    const passwordLengthElement = document.querySelector('.twdpsc_contains_eight_characters');
    const containsNumberElement = document.querySelector('.twdpsc_contains_number');
    const containsUppercaseElement = document.querySelector('.twdpsc_contains_uppercase');
    const containsSpecialCharacterElement = document.querySelector('.twdpsc_contains_special_character');

    // Check if password has 8 or more characters
    passwordLengthElement.classList.toggle("twdpsc_is_valid", password.length >= 8);

    // Check if password contains a number
    containsNumberElement.classList.toggle("twdpsc_is_valid", /\d/.test(password));

    // Check if password contains an uppercase letter
    containsUppercaseElement.classList.toggle("twdpsc_is_valid", /[A-Z]/.test(password));

    // Check if password contains a special character
    containsSpecialCharacterElement.classList.toggle("twdpsc_is_valid", /[ !@#$%^&*()_+\-=\[\]{};':"\\|,.<>\/?]/.test(password));

    // Check if all criteria are met
    const validPassword = password.length >= 8;
                          /\d/.test(password) &&
                          /[A-Z]/.test(password) &&
                          /[ !@#$%^&*()_+\-=\[\]{};':"\\|,.<>\/?]/.test(password);

    twdpsc_checkmark.innerHTML = validPassword ? '<div class="twdpsc_checkmark twdpsc_checkmark_checked"></div>' : '';

}